==> nextcloud-app-notes-4.6.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/he.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "הערות",
    "Reading notes from filesystem has failed." : "קריאת הפתקים ממערכת הקבצים נכשלה.",
    "Error" : "שגיאה",
    "New note" : "פתק חדש",
    "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
    "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
    "Deleted {title}" : "{title} נמחק",
    "Undo Delete" : "ביטול מחיקה",
    "Note recovered" : "הפתק שוחזר",
    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו","{number} פתקים נמחקו"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
    "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
    "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
    "Display mode for notes" : "מצב תצוגת פתקים",
    "Open in edit mode" : "פתיחה במצב עריכה",
    "Open in preview mode" : "פתיחה במצב תצוגה מקדימה",
    "No notes yet" : "אין פתקים עדיין",
    "Insert image" : "הוספת תמונה",
    "All notes" : "כל הפתקים",
    "Categories" : "קטגוריות",
    "Loading …" : "בטעינה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "This week" : "השבוע",
    "Last week" : "שבוע שעבר",
    "This month" : "החודש",
    "Last month" : "חודש שעבר",
    "Rename" : "שינוי שם",
    "Note's title" : "הכותרת של הפתק",
    "Delete note" : "מחיקת פתק",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Error during preparing note for deletion." : "שגיאה במהלך הכנת הפתק למחיקה.",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Empty note" : "פתק ריק",
    "Write …" : "כתיבה…",
    "Details" : "פרטים",
    "CTRL + /" : "CTRL + /‎",
    "Edit" : "עריכה",
    "Preview" : "תצוגה מקדימה",
    "Exit full screen" : "יציאה ממסך מלא",
    "Full screen" : "מסך מלא",
    "Save failed. Click to retry." : "השמירה נכשלה. יש ללחוץ כדי לנסות שוב.",
    "Error from Nextcloud server: {msg}" : "שגיאה משרת ה־Nextcloud:‏ {msg}",
    "Set category" : "הגדרת קטגוריה",
    "Category" : "קטגוריה",
    "Uncategorized" : "ללא קטגוריה",
    "Click here to save manually" : "יש ללחוץ כאן כדי לשמור ידנית",
    "Saving failed!" : "השמירה נכשלה!",
    "Last modified: {date}" : "שינוי אחרון: {date}",
    "Note has unsaved changes" : "יש שינויים בפתק שטרם נשמרו",
    "Subcategory" : "תת־קטגוריה",
    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
    "_%n character_::_%n characters_" : ["תו אחד","%n תווים","%n תווים","%n תווים"],
    "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
    "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
    "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "יש להתקין את היישומון לטלפון הנייד שלך כדי לגשת לפתקים שלך מכל מקום.",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "ניתן ליצור תת־קטגוריות על ידי שימוש ב־„/” כמפריד בין קטגוריית ההורה ותת־הקטגוריה, למשל: „‎{parent}/{sub}‎”.",
    "Note not found." : "הפתק לא נמצא.",
    "Note is locked." : "הפתק נעול.",
    "Insufficient storage." : "אין מספיק שטח אחסון.",
    "See JavaScript console and server log for details." : "ניתן להביט במסוף ה־JavaScript וביומן השרת לקבלת פרטים.",
    "Updating settings has failed." : "עדכון ההגדרות נכשל.",
    "Fetching notes has failed." : "קבלת הפתקים נכשלה.",
    "Fetching note {id} has failed." : "קבלת הפתק {id} נכשלה.",
    "Refreshing note {id} has failed." : "רענון הפתק {id} נכשל.",
    "Renaming note {id} has failed." : "שינוי שם הפתק {id} נכשל.",
    "Creating new note has failed." : "יצירת פתק חדש נכשלה.",
    "Saving note {id} has failed." : "שמירת הפתק {id} נכשלה.",
    "Updating title for note {id} has failed." : "עדכון כותרת הפתק {id} נכשלה.",
    "Undo delete has failed for note {title}." : "ביטול מחיקת הפתק {title} נכשלה.",
    "Deleting note {id} has failed." : "מחיקת הפתק {id} נכשלה.",
    "Toggling favorite for note {id} has failed." : "החלפת מצב העדפה לפתק {id} נכשלה.",
    "Updating the note's category has failed. Is the target directory writable?" : "עדכון קטגוריית הפתק נכשלה. האם תיקיית היעד נגישה לכתיבה?",
    "Updating the category for note {id} has failed." : "עדכון הקטגוריה של הפתק {id} נכשלה.",
    "Development Mode" : "מצב פיתוח"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-notes-4.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/he.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "הערות",
    "Reading notes from filesystem has failed." : "קריאת הפתקים ממערכת הקבצים נכשלה.",
    "Error" : "שגיאה",
    "New note" : "פתק חדש",
    "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
    "Help" : "עזרה",
    "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
    "Deleted {title}" : "{title} נמחק",
    "Undo Delete" : "ביטול מחיקה",
    "Note recovered" : "הפתק שוחזר",
    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו","{number} פתקים נמחקו"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
    "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
    "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
    "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
    "Result" : "תוצאה",
    "Shortcuts" : "קיצורי דרך",
    "Action" : "פעולה",
    "Insert image" : "הוספת תמונה",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
    "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
    "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
    "Display mode for notes" : "מצב תצוגת פתקים",
    "Open in edit mode" : "פתיחה במצב עריכה",
    "Open in preview mode" : "פתיחה במצב תצוגה מקדימה",
    "No notes yet" : "אין פתקים עדיין",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "יש להתקין את היישומון לטלפון הנייד שלך כדי לגשת לפתקים שלך מכל מקום.",
    "All notes" : "כל הפתקים",
    "Categories" : "קטגוריות",
    "Loading …" : "בטעינה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "This week" : "השבוע",
    "Last week" : "שבוע שעבר",
    "This month" : "החודש",
    "Last month" : "חודש שעבר",
    "Rename" : "שינוי שם",
    "Note's title" : "הכותרת של הפתק",
    "Details" : "פרטים",
    "Delete note" : "מחיקת פתק",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Error during preparing note for deletion." : "שגיאה במהלך הכנת הפתק למחיקה.",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Empty note" : "פתק ריק",
    "Write …" : "כתיבה…",
    "CTRL + /" : "CTRL + /‎",
    "Edit" : "עריכה",
    "Preview" : "תצוגה מקדימה",
    "Exit full screen" : "יציאה ממסך מלא",
    "Full screen" : "מסך מלא",
    "Save failed. Click to retry." : "השמירה נכשלה. יש ללחוץ כדי לנסות שוב.",
    "Error from Nextcloud server: {msg}" : "שגיאה משרת ה־Nextcloud:‏ {msg}",
    "Category" : "קטגוריה",
    "Uncategorized" : "ללא קטגוריה",
    "Set category" : "הגדרת קטגוריה",
    "Click here to save manually" : "יש ללחוץ כאן כדי לשמור ידנית",
    "Saving failed!" : "השמירה נכשלה!",
    "Last modified: {date}" : "שינוי אחרון: {date}",
    "Note has unsaved changes" : "יש שינויים בפתק שטרם נשמרו",
    "Subcategory" : "תת־קטגוריה",
    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
    "_%n character_::_%n characters_" : ["תו אחד","%n תווים","%n תווים","%n תווים"],
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "ניתן ליצור תת־קטגוריות על ידי שימוש ב־„/” כמפריד בין קטגוריית ההורה ותת־הקטגוריה, למשל: „‎{parent}/{sub}‎”.",
    "Note not found." : "הפתק לא נמצא.",
    "Note is locked." : "הפתק נעול.",
    "Insufficient storage." : "אין מספיק שטח אחסון.",
    "See JavaScript console and server log for details." : "ניתן להביט במסוף ה־JavaScript וביומן השרת לקבלת פרטים.",
    "Updating settings has failed." : "עדכון ההגדרות נכשל.",
    "Fetching notes has failed." : "קבלת הפתקים נכשלה.",
    "Fetching note {id} has failed." : "קבלת הפתק {id} נכשלה.",
    "Refreshing note {id} has failed." : "רענון הפתק {id} נכשל.",
    "Renaming note {id} has failed." : "שינוי שם הפתק {id} נכשל.",
    "Creating new note has failed." : "יצירת פתק חדש נכשלה.",
    "Saving note {id} has failed." : "שמירת הפתק {id} נכשלה.",
    "Updating title for note {id} has failed." : "עדכון כותרת הפתק {id} נכשלה.",
    "Undo delete has failed for note {title}." : "ביטול מחיקת הפתק {title} נכשלה.",
    "Deleting note {id} has failed." : "מחיקת הפתק {id} נכשלה.",
    "Toggling favorite for note {id} has failed." : "החלפת מצב העדפה לפתק {id} נכשלה.",
    "Updating the note's category has failed. Is the target directory writable?" : "עדכון קטגוריית הפתק נכשלה. האם תיקיית היעד נגישה לכתיבה?",
    "Updating the category for note {id} has failed." : "עדכון הקטגוריה של הפתק {id} נכשלה.",
    "Tasks" : "משימות",
    "Development Mode" : "מצב פיתוח"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
